##################################################################################################
######### gen_empty_desc.sh : Generate empty description file
##################################################################################################

#!/bin/sh

export LANG=POSIX

FILE_OWNER="www-data"
FILE_GROUP="www-data"
FILE_MOD="644"

if [ $# -lt 1 ]
then 
	echo "Usage : $0 gallery_path"
	exit 1;
fi

GALLERY_PATH=$1
DESCRIPTION_FILE=description.txt
HEADER=header.html
FOOTER=footer.html
INDEX_FILE=index.html
VIEW_IMG_FILE=view_template.html
VIEW_VID_FILE=view_video_template.html


if [ ! -d ${GALLERY_PATH} ]
then    
        echo "Error : ${GALLERY_PATH} is not a directory or doesn't exists."
	exit 2;
fi
		
cd ${GALLERY_PATH}

if [ ! -f ${DESCRIPTION_FILE} ]
then
	echo "ERROR : Description file doesn't exists (${DESCRIPTION_FILE})"
	exit 2;
fi

if [ ! -f ${HEADER} ]
then
	echo "ERROR : Header file doesn't exists (${HEADER})"
	exit 2;
fi

if [ ! -f ${FOOTER} ]
then
	echo "ERROR : Footer file doesn't exists (${FOOTER})"
	exit 2;
fi

TEMPLATE_EVERY_X=`find . -maxdepth 1 -name "template_every_[0-9]*\.html" -printf "%f\n" | sed -e "s/template_every_\([0-9]*\)\.html/\1/g" | sort -n`

HEADER_LINE=`grep -n -m 1 "^FILENAME:" ${DESCRIPTION_FILE} | cut -d: -f1`
echo "Creating index file in ${GALLERY_PATH}."
GALLERYNAME=`head -n ${HEADER_LINE} ${DESCRIPTION_FILE} | grep -m 1 "^GALLERYNAME:" | sed -e "s/^GALLERYNAME:\(.*\)$/\1/"`
echo "Gallery name : ${GALLERYNAME}"
GALLERYDESC=`head -n ${HEADER_LINE} ${DESCRIPTION_FILE} | grep -m 1 "^GALLERYDESC:" | sed -e "s/^GALLERYDESC:\(.*\)$/\1/"`
echo "Gallery description : ${GALLERYDESC}"
GALLERYICON=`head -n ${HEADER_LINE} ${DESCRIPTION_FILE} | grep -m 1 "^GALLERYICON:" | sed -e "s/^GALLERYICON:\(.*\)$/\1/"`
echo "Gallery icon : ${GALLERYICON}"


IMAGE_LIST=`grep -n "^FILENAME:.*" ${DESCRIPTION_FILE} | cut -d: -f1`
LINE_COUNT=`wc -l ${DESCRIPTION_FILE} | awk '{print $1+1 }'`
IMAGE_LIST=`echo -e "${IMAGE_LIST}\n${LINE_COUNT}"`
IMAGE_COUNT="0"

cat ${HEADER} \
	| sed -e "s/<GALLERYNAME>/${GALLERYNAME}/g" \
	| sed -e "s/<GALLERYDESC>/${GALLERYDESC}/g" \
	| sed -e "s/<GALLERYICON>/${GALLERYICON}/g" \
	| sed -e "s/<FILENAME>/${FILENAME}/g" \
	| sed -e "s/<SHORTDESC>/${SHORTDESC}/g" \
	| sed -e "s/<LONGDESC>/${LONGDESC}/g" \
	> ${INDEX_FILE}

for IMAGE in ${IMAGE_LIST}
do
	if [ ${IMAGE_COUNT} -gt 0 ]
	then
		for EVERY_X in ${TEMPLATE_EVERY_X}
		do
			CHECK_EVERY_X=`expr ${IMAGE_COUNT} % ${EVERY_X}`
			if [ ${CHECK_EVERY_X} -eq 0 ]
			then
				NB_LINE=`expr ${IMAGE} - ${CUR_IMAGE}`
				HEAD_COUNT=`expr ${IMAGE} - 1`
				FILENAME=`head -n ${HEAD_COUNT} ${DESCRIPTION_FILE} | tail -n ${NB_LINE} | grep -m 1 "^FILENAME:" | sed -e "s/^FILENAME:\(.*\)$/\1/"`
				SHORTDESC=`head -n ${HEAD_COUNT} ${DESCRIPTION_FILE} | tail -n ${NB_LINE} | grep -m 1 "^SHORTDESC:" | sed -e "s/^SHORTDESC:\(.*\)$/\1/"`
				LONGDESC=`head -n ${HEAD_COUNT} ${DESCRIPTION_FILE} | tail -n ${NB_LINE} | grep -m 1 "^LONGDESC:" | sed -e "s/^LONGDESC:\(.*\)$/\1/"`
				if [ `echo ${FILENAME} | grep -e "\.AVI$" -e "\.MOV$" | wc -l ` != 0 ]
				then
					cat template_video_every_${EVERY_X}.html \
						| sed -e "s/<GALLERYNAME>/${GALLERYNAME}/g" \
						| sed -e "s/<GALLERYDESC>/${GALLERYDESC}/g" \
						| sed -e "s/<GALLERYICON>/${GALLERYICON}/g" \
						| sed -e "s/<FILENAME>/${FILENAME}/g" \
						| sed -e "s/<SHORTDESC>/${SHORTDESC}/g" \
						| sed -e "s/<LONGDESC>/${LONGDESC}/g" \
						>> ${INDEX_FILE}
				else
					cat template_every_${EVERY_X}.html \
						| sed -e "s/<GALLERYNAME>/${GALLERYNAME}/g" \
						| sed -e "s/<GALLERYDESC>/${GALLERYDESC}/g" \
						| sed -e "s/<GALLERYICON>/${GALLERYICON}/g" \
						| sed -e "s/<FILENAME>/${FILENAME}/g" \
						| sed -e "s/<SHORTDESC>/${SHORTDESC}/g" \
						| sed -e "s/<LONGDESC>/${LONGDESC}/g" \
						>> ${INDEX_FILE}
				fi
			fi
		done
		if [ `echo ${FILENAME} | grep -e "\.AVI$" -e "\.MOV$" | wc -l ` != 0 ]
		then
			cat ${VIEW_VID_FILE} \
				| sed -e "s/<GALLERYNAME>/${GALLERYNAME}/g" \
				| sed -e "s/<GALLERYDESC>/${GALLERYDESC}/g" \
				| sed -e "s/<GALLERYICON>/${GALLERYICON}/g" \
				| sed -e "s/<FILENAME>/${FILENAME}/g" \
				| sed -e "s/<SHORTDESC>/${SHORTDESC}/g" \
				| sed -e "s/<LONGDESC>/${LONGDESC}/g" \
				> view_${FILENAME}.html
		else
			cat ${VIEW_IMG_FILE} \
				| sed -e "s/<GALLERYNAME>/${GALLERYNAME}/g" \
				| sed -e "s/<GALLERYDESC>/${GALLERYDESC}/g" \
				| sed -e "s/<GALLERYICON>/${GALLERYICON}/g" \
				| sed -e "s/<FILENAME>/${FILENAME}/g" \
				| sed -e "s/<SHORTDESC>/${SHORTDESC}/g" \
				| sed -e "s/<LONGDESC>/${LONGDESC}/g" \
				> view_${FILENAME}.html
		fi
	fi

	CUR_IMAGE="${IMAGE}"
	IMAGE_COUNT=`expr ${IMAGE_COUNT} + 1`
done

cat ${FOOTER} \
	| sed -e "s/<GALLERYNAME>/${GALLERYNAME}/g" \
	| sed -e "s/<GALLERYDESC>/${GALLERYDESC}/g" \
	| sed -e "s/<GALLERYICON>/${GALLERYICON}/g" \
	| sed -e "s/<FILENAME>/${FILENAME}/g" \
	| sed -e "s/<SHORTDESC>/${SHORTDESC}/g" \
	| sed -e "s/<LONGDESC>/${LONGDESC}/g" \
	>> ${INDEX_FILE}

IMAGE_COUNT=`expr ${IMAGE_COUNT} - 1`

echo "${IMAGE_COUNT} images processed"

echo "Changing description file owner."
chown ${FILE_OWNER}.${FILE_GROUP} ${INDEX_FILE}
echo "Changing description file access permissions."
chmod ${FILE_MOD} ${INDEX_FILE}
