##################################################################################################
######### gen_museum.sh : Generate museum
##################################################################################################

#!/bin/sh

export LANG=POSIX

FILE_OWNER="www-data"
FILE_GROUP="www-data"
FILE_MOD="644"

if [ $# -lt 1 ]
then 
	echo "Usage : $0 gallery_path"
	exit 1;
fi

MUSEUM_PATH=$1
DESCRIPTION_FILE=description_museum.txt
DESCRIPTION_GALLERY_FILE=description.txt
HEADER=header.html
FOOTER=footer.html
INDEX_FILE=index.html

if [ ! -d ${MUSEUM_PATH} ]
then    
        echo "Error : ${MUSEUM_PATH} is not a directory or doesn't exists."
	exit 2;
fi
		
cd ${MUSEUM_PATH}

if [ ! -f ${DESCRIPTION_FILE} ]
then
	echo "ERROR : Description file doesn't exists (${DESCRIPTION_FILE})"
	exit 2;
fi

if [ ! -f ${HEADER} ]
then
	echo "ERROR : Header file doesn't exists (${HEADER})"
	exit 2;
fi

if [ ! -f ${FOOTER} ]
then
	echo "ERROR : Footer file doesn't exists (${FOOTER})"
	exit 2;
fi

TEMPLATE_EVERY_X=`find . -maxdepth 1 -type f -name "template_every_[0-9]*\.html" -printf "%f\n" | sed -e "s/template_every_\([0-9]*\)\.html/\1/g" | sort -n`

echo "Creating index file in ${MUSEUM_PATH}."

MUSEUMNAME=`grep -m 1 "^MUSEUMNAME:" ${DESCRIPTION_FILE} | sed -e "s/^MUSEUMNAME:\(.*\)$/\1/"`
echo "Museum name : ${MUSEUMNAME}"
MUSEUMDESC=`grep -m 1 "^MUSEUMDESC:" ${DESCRIPTION_FILE} | sed -e "s/^MUSEUMDESC:\(.*\)$/\1/"`
echo "Museum description : ${MUSEUMDESC}"
MUSEUMICON=`grep -m 1 "^MUSEUMICON:" ${DESCRIPTION_FILE} | sed -e "s/^MUSEUMICON:\(.*\)$/\1/"`

cat ${HEADER} \
	| sed -e "s/<MUSEUMNAME>/${MUSEUMNAME}/g" \
	| sed -e "s/<MUSEUMDESC>/${MUSEUMDESC}/g" \
	| sed -e "s/<MUSEUMICON>/${MUSEUMICON}/g" \
	> ${INDEX_FILE}

DESCRIPTION_GALLERY_LIST=`find . -name ${DESCRIPTION_GALLERY_FILE} -type f`
GALLERY_COUNT=0

for DESCRIPTION_GALLERY in ${DESCRIPTION_GALLERY_LIST}
do
	GALLERYPATH=`echo ${DESCRIPTION_GALLERY} | sed -e "s/${DESCRIPTION_GALLERY_FILE}//" `
	HEADER_LINE=`grep -n -m 1 "^FILENAME:" ${DESCRIPTION_GALLERY} | cut -d: -f1`
	GALLERYNAME=`head -n ${HEADER_LINE} ${DESCRIPTION_GALLERY} | grep -m 1 "^GALLERYNAME:" | sed -e "s/^GALLERYNAME:\(.*\)$/\1/"`
	echo "Gallery name : ${GALLERYNAME}"
	GALLERYDESC=`head -n ${HEADER_LINE} ${DESCRIPTION_GALLERY} | grep -m 1 "^GALLERYDESC:" | sed -e "s/^GALLERYDESC:\(.*\)$/\1/"`
	echo "Gallery description : ${GALLERYDESC}"
	GALLERYICON=`head -n ${HEADER_LINE} ${DESCRIPTION_GALLERY} | grep -m 1 "^GALLERYICON:" | sed -e "s/^GALLERYICON:\(.*\)$/\1/"`
	echo "Gallery icon : ${GALLERYICON}"

	for EVERY_X in ${TEMPLATE_EVERY_X}
	do
		CHECK_EVERY_X=`expr ${GALLERY_COUNT} % ${EVERY_X}`
		if [ ${CHECK_EVERY_X} -eq 0 ]
		then
			cat template_every_${EVERY_X}.html \
				| sed -e "s,<GALLERYPATH>,${GALLERYPATH},g" \
				| sed -e "s/<MUSEUMNAME>/${MUSEUMNAME}/g" \
				| sed -e "s/<MUSEUMDESC>/${MUSEUMDESC}/g" \
				| sed -e "s/<MUSEUMICON>/${MUSEUMICON}/g" \
				| sed -e "s/<GALLERYNAME>/${GALLERYNAME}/g" \
				| sed -e "s/<GALLERYDESC>/${GALLERYDESC}/g" \
				| sed -e "s/<GALLERYICON>/${GALLERYICON}/g" \
				| sed -e "s/<FILENAME>/${FILENAME}/g" \
				| sed -e "s/<SHORTDESC>/${SHORTDESC}/g" \
				| sed -e "s/<LONGDESC>/${LONGDESC}/g" \
				>> ${INDEX_FILE}
		fi
		GALLERY_COUNT=`expr ${GALLERY_COUNT} + 1`
	done
done

cat ${FOOTER} \
	| sed -e "s/<MUSEUMNAME>/${MUSEUMNAME}/g" \
	| sed -e "s/<MUSEUMDESC>/${MUSEUMDESC}/g" \
	| sed -e "s/<MUSEUMICON>/${MUSEUMICON}/g" \
	| sed -e "s/<GALLERYNAME>/${GALLERYNAME}/g" \
	| sed -e "s/<GALLERYDESC>/${GALLERYDESC}/g" \
	| sed -e "s/<GALLERYICON>/${GALLERYICON}/g" \
	| sed -e "s/<FILENAME>/${FILENAME}/g" \
	| sed -e "s/<SHORTDESC>/${SHORTDESC}/g" \
	| sed -e "s/<LONGDESC>/${LONGDESC}/g" \
	>> ${INDEX_FILE}

echo "${GALLERY_COUNT} gallery processed"

echo "Changing description file owner."
chown ${FILE_OWNER}.${FILE_GROUP} ${INDEX_FILE}
echo "Changing description file access permissions."
chmod ${FILE_MOD} ${INDEX_FILE}
